API docs for “spamfighter.core.message.serialize.ITransitMessage”

# Class s.c.m.s.ITransitMessage(ISerializable):

Part of spamfighter.core.message.serialize View Source View In Hierarchy

Вариант сообщения, которое передается в сериализованном представлении через параметры команд.

Method | getMessage | Окончательно десериализовать сообщение относительно домена.

Inherited from ISerializable:

Method | serialize | Получить сериализованное представление элемента.
Method | unserialize | Восстановить экземпляр объекта из его сериализованного представления

def getMessage(domain): (source)
Окончательно десериализовать сообщение относительно домена.

Parameters | domain | домен, относительно которого десериализуется сообщение (type: `spamfighter.interfaces.IDomain` )